@BOTTOM@

/* Do we have getaddrinfo()? */
#undef HAVE_GETADDRINFO_PROTO

/* Do we have POSIX signals? */
#undef HAVE_SIGACTION

/* Do we have T/TCP? */
#undef HAVE_TTCP

/* Do we have TOS? */
#undef HAVE_TOS

/* Do we have socket priority? */
#undef HAVE_SOCKET_PRIORITY

/* Is sys_errlist declared? */
#undef DECL_SYS_ERRLIST

/* Is sys_nerr declared? */
#undef DECL_SYS_NERR

/* HTTP support */
#undef HTTP 

/* SMTP support */
#undef SMTP

/* ICP support */
#undef ICP 

/* SSL (crypto) */
#undef OPENSSL

/* Port name for HTTP. Unused. */
#undef HTTP_TCP_PORT

/* Port name for ICP */
#undef ICP_UDP_PORT

#undef PACKAGE
#undef VERSION

/* $Id: acconfig.h,v 4.3 2001/03/19 09:38:32 bortz Exp $ */
